/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gnome;

import org.gnu.glib.GObject;
import org.gnu.glib.Handle;

/**
 *
 */
public class UIBuilderData extends GObject 
{
	
	public UIBuilderData(Handle handle) {
		super(handle);
	}

    native static final protected int getData (Handle cptr);
    native static final protected boolean getIsInterp (Handle cptr);

}

